@@ -40,14 +40,17 @@
 typedef enum {
 	GCM_CALIBRATE_PAGE_INTRO,
 	GCM_CALIBRATE_PAGE_DISPLAY_KIND,
+	GCM_CALIBRATE_PAGE_DISPLAY_TEMPERATURE,
 	GCM_CALIBRATE_PAGE_DISPLAY_CONFIG,
 	GCM_CALIBRATE_PAGE_INSTALL_ARGYLLCMS,
 	GCM_CALIBRATE_PAGE_INSTALL_TARGETS,
+	GCM_CALIBRATE_PAGE_PRECISION,
 	GCM_CALIBRATE_PAGE_PRINT_KIND,
 	GCM_CALIBRATE_PAGE_TARGET_KIND,
 	GCM_CALIBRATE_PAGE_SENSOR,
 	GCM_CALIBRATE_PAGE_ACTION,
 	GCM_CALIBRATE_PAGE_FAILURE,
+	GCM_CALIBRATE_PAGE_TITLE,
 	GCM_CALIBRATE_PAGE_LAST
 } GcmCalibratePage;
 
@@ -72,11 +75,7 @@ typedef struct {
 	GtkWidget	*action_image;
 	gboolean	 has_pending_interaction;
 	gboolean	 started_calibration;
-	GcmCalibrateDisplayKind		 display_kind;
-	GcmCalibrateReferenceKind	 reference_kind;
-	GcmCalibratePrintKind		 print_kind;
-	GcmCalibratePrecision		 precision;
-	GcmCalibratePage		 current_page;
+	GcmCalibratePage current_page;
 } GcmCalibratePriv;
 
 /**
@@ -312,17 +311,46 @@ gcm_calib_get_vbox_for_page (GcmCalibratePriv *calib,
 	return NULL;
 }
 
+static wchar_t *
+utf8_to_wchar_t (const char *src)
+{
+	gsize len;
+	gsize converted;
+	wchar_t *buf = NULL;
+
+	len = mbstowcs (NULL, src, 0);
+	if (len == (gsize) -1) {
+		g_warning ("Invalid UTF-8 in string %s", src);
+		goto out;
+	}
+	len += 1;
+	buf = g_malloc (sizeof (wchar_t) * len);
+	converted = mbstowcs (buf, src, len - 1);
+	g_assert (converted != (gsize) -1);
+	buf[converted] = '\0';
+out:
+	return buf;
+}
+
 static cmsBool
 _cmsDictAddEntryAscii (cmsHANDLE dict,
 		       const gchar *key,
 		       const gchar *value)
 {
-	cmsBool ret;
-	wchar_t mb_key[1024];
-	wchar_t mb_value[1024];
-	mbstowcs (mb_key, key, sizeof (mb_key));
-	mbstowcs (mb_value, value, sizeof (mb_value));
+	cmsBool ret = FALSE;
+	wchar_t *mb_key = NULL;
+	wchar_t *mb_value = NULL;
+
+	mb_key = utf8_to_wchar_t (key);
+	if (mb_key == NULL)
+		goto out;
+	mb_value = utf8_to_wchar_t (value);
+	if (mb_value == NULL)
+		goto out;
 	ret = cmsDictAddEntry (dict, mb_key, mb_value, NULL, NULL);
+out:
+	g_free (mb_key);
+	g_free (mb_value);
 	return ret;
 }
 
@@ -394,20 +422,12 @@ gcm_calib_start_idle_cb (gpointer user_data)
 	CdProfile *profile = NULL;
 	const gchar *filename;
 	gboolean ret;
-	gchar *destination = NULL;
-	gchar *filename_dest = NULL;
 	GError *error = NULL;
-	GFile *dest = NULL;
 	GFile *file = NULL;
 	GtkWidget *vbox;
 	GcmCalibratePriv *calib = (GcmCalibratePriv *) user_data;
 	GtkAssistant *assistant = GTK_ASSISTANT (calib->main_window);
 
-	g_object_set (calib->calibrate,
-		      "display-kind", calib->display_kind,
-		      "precision", calib->precision,
-		      NULL);
-
 	/* actuall do the action */
 	calib->started_calibration = TRUE;
 	ret = gcm_calibrate_display (calib->calibrate,
@@ -447,20 +467,10 @@ gcm_calib_start_idle_cb (gpointer user_data)
 
 	/* copy the ICC file to the proper location */
 	file = g_file_new_for_path (filename);
-	dest = gcm_utils_get_profile_destination (file);
-	ret = gcm_utils_mkdir_and_copy (file, dest, &error);
-	if (!ret) {
-		g_warning ("failed to calibrate: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* add the new profile as the default */
-	filename_dest = g_file_get_path (dest);
-	profile = cd_client_find_profile_by_filename_sync (calib->client,
-							   filename_dest,
-							   calib->cancellable,
-							   &error);
+	profile = cd_client_import_profile_sync (calib->client,
+						 file,
+						 calib->cancellable,
+						 &error);
 	if (profile == NULL) {
 		g_warning ("failed to find calibration profile: %s",
 			   error->message);
@@ -484,15 +494,20 @@ gcm_calib_start_idle_cb (gpointer user_data)
 	/* remove temporary file */
 	g_unlink (filename);
 
+	/* allow forward */
+	vbox = gcm_calib_get_vbox_for_page (calib,
+					    GCM_CALIBRATE_PAGE_ACTION);
+	gtk_assistant_set_page_complete (assistant,
+					 vbox, TRUE);
+
+	/* set to summary page */
+	gtk_assistant_set_current_page (assistant,
+					gtk_assistant_get_n_pages (assistant) - 1);
 out:
-	g_free (destination);
-	g_free (filename_dest);
 	if (profile != NULL)
 		g_object_unref (profile);
 	if (file != NULL)
 		g_object_unref (file);
-	if (dest != NULL)
-		g_object_unref (dest);
 	return FALSE;
 }
 
@@ -516,7 +531,6 @@ gcm_calib_assistant_page_forward_cb (gint current_page, gpointer user_data)
 	vbox = gcm_calib_get_vbox_for_page (calib,
 					    GCM_CALIBRATE_PAGE_ACTION);
 
-
 	gtk_assistant_set_page_complete (GTK_ASSISTANT (calib->main_window),
 					 vbox, FALSE);
 	return current_page;
@@ -526,16 +540,14 @@ gcm_calib_assistant_page_forward_cb (gint current_page, gpointer user_data)
  * gcm_calib_assistant_prepare_cb:
  **/
 static gboolean
-gcm_calib_assistant_prepare_cb (GtkAssistant *assistant, GtkWidget *page_widget, GcmCalibratePriv *calib)
+gcm_calib_assistant_prepare_cb (GtkAssistant *assistant,
+				GtkWidget *page_widget,
+				GcmCalibratePriv *calib)
 {
 	calib->current_page = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (page_widget),
 								   "GcmCalibrateMain::Index"));
 	switch (calib->current_page) {
-	case GCM_CALIBRATE_PAGE_INTRO:
-		g_debug ("now intro page");
-		break;
 	case GCM_CALIBRATE_PAGE_LAST:
-		g_debug ("now last page");
 		gcm_calib_device_uninihibit (calib);
 		gcm_calib_play_sound (calib);
 		break;
@@ -550,6 +562,15 @@ gcm_calib_assistant_prepare_cb (GtkAssistant *assistant, GtkWidget *page_widget,
 		break;
 	}
 
+	/* ensure we cancel argyllcms if the user clicks back */
+	if (calib->current_page != GCM_CALIBRATE_PAGE_ACTION &&
+	    calib->started_calibration) {
+		gcm_calibrate_interaction (calib->calibrate,
+					   GTK_RESPONSE_CANCEL);
+		gcm_calib_device_uninihibit (calib);
+		calib->started_calibration = FALSE;
+	}
+
 	/* forward on the action page just unsticks the calibration */
 	if (calib->current_page == GCM_CALIBRATE_PAGE_ACTION) {
 		gtk_assistant_set_forward_page_func (assistant,
@@ -1135,10 +1156,11 @@ gcm_calib_reference_kind_combobox_cb (GtkComboBox *combo_box,
 {
 	const gchar *filename;
 	gchar *path;
+	GcmCalibrateReferenceKind reference_kind;
 
 	/* not sorted so we can just use the index */
-	calib->reference_kind = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box));
-	filename = gcm_calib_reference_kind_to_image_filename (calib->reference_kind);
+	reference_kind = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box));
+	filename = gcm_calib_reference_kind_to_image_filename (reference_kind);
 
 	/* fallback */
 	if (filename == NULL)
@@ -1234,10 +1256,15 @@ static void
 gcm_calib_display_kind_toggled_cb (GtkToggleButton *togglebutton,
 				   GcmCalibratePriv *calib)
 {
+	GcmCalibrateDisplayKind	 display_kind;
+
 	if (!gtk_toggle_button_get_active (togglebutton))
 		return;
-	calib->display_kind = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (togglebutton),
-								   "GcmCalib::display-kind"));
+	display_kind = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (togglebutton),
+							    "GcmCalib::display-kind"));
+	g_object_set (calib->calibrate,
+		      "display-kind", display_kind,
+		      NULL);
 }
 
 /**
@@ -1312,14 +1339,114 @@ gcm_calib_setup_page_display_kind (GcmCalibratePriv *calib)
 	gtk_widget_show_all (vbox);
 }
 
+static void
+gcm_calib_display_temp_toggled_cb (GtkToggleButton *togglebutton,
+				   GcmCalibratePriv *calib)
+{
+	guint display_temp;
+	if (!gtk_toggle_button_get_active (togglebutton))
+		return;
+	display_temp = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (togglebutton),
+							    "GcmCalib::display-temp"));
+	g_object_set (calib->calibrate,
+		      "target-whitepoint", display_temp,
+		      NULL);
+}
+
+/**
+ * gcm_calib_setup_page_display_temp:
+ **/
+static void
+gcm_calib_setup_page_display_temp (GcmCalibratePriv *calib)
+{
+	GtkWidget *vbox;
+	GtkWidget *content;
+	GtkWidget *widget;
+	GSList *list;
+	GtkAssistant *assistant = GTK_ASSISTANT (calib->main_window);
+
+	/* TRANSLATORS: this is the page title */
+	vbox = gcm_calib_add_page_title (calib, _("Choose your display target white point"));
+
+	/* main contents */
+	content = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), content, FALSE, FALSE, 0);
+
+	/* TRANSLATORS: this is intro page text */
+	gcm_calib_add_page_para (content, _("Most displays should be calibrated to a CIE D65 illuminant for general usage."));
+
+	widget = gtk_radio_button_new_with_label (NULL, _("CIE D50 (Printing and publishing)"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-temp",
+			   GUINT_TO_POINTER (5000));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_temp_toggled_cb), calib);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+
+	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+	widget = gtk_radio_button_new_with_label (list, _("CIE D55"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-temp",
+			   GUINT_TO_POINTER (5500));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_temp_toggled_cb), calib);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+
+	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+	widget = gtk_radio_button_new_with_label (list, _("CIE D65 (Photography and graphics)"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-temp",
+			   GUINT_TO_POINTER (6500));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_temp_toggled_cb), calib);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
+
+	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+	widget = gtk_radio_button_new_with_label (list, _("CIE D75"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-temp",
+			   GUINT_TO_POINTER (7500));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_temp_toggled_cb), calib);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+
+	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+	widget = gtk_radio_button_new_with_label (list, _("Native (Already set manually)"));
+	g_object_set_data (G_OBJECT (widget),
+			   "GcmCalib::display-temp",
+			   GUINT_TO_POINTER (0));
+	g_signal_connect (widget, "toggled",
+			  G_CALLBACK (gcm_calib_display_temp_toggled_cb), calib);
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+
+	/* add to assistant */
+	gtk_assistant_append_page (assistant, vbox);
+	gtk_assistant_set_page_type (assistant, vbox, GTK_ASSISTANT_PAGE_CONTENT);
+	/* TRANSLATORS: this is the calibration wizard page title */
+	gtk_assistant_set_page_title (assistant, vbox, _("Choose Display Whitepoint"));
+	gtk_assistant_set_page_complete (assistant, vbox, FALSE);
+	g_ptr_array_add (calib->pages, vbox);
+	g_object_set_data (G_OBJECT (vbox),
+			   "GcmCalibrateMain::Index",
+			   GUINT_TO_POINTER (GCM_CALIBRATE_PAGE_DISPLAY_TEMPERATURE));
+
+	/* show page */
+	gtk_widget_show_all (vbox);
+}
+
 static void
 gcm_calib_print_kind_toggled_cb (GtkToggleButton *togglebutton,
 				   GcmCalibratePriv *calib)
 {
+	GcmCalibratePrintKind print_kind;
 	if (!gtk_toggle_button_get_active (togglebutton))
 		return;
-	calib->print_kind = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (togglebutton),
-								   "GcmCalib::print-kind"));
+	print_kind = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (togglebutton),
+							  "GcmCalib::print-kind"));
+	g_object_set (calib->calibrate,
+		      "print-kind", print_kind,
+		      NULL);
 }
 
 /**
@@ -1389,10 +1516,14 @@ static void
 gcm_calib_precision_toggled_cb (GtkToggleButton *togglebutton,
 				GcmCalibratePriv *calib)
 {
+	GcmCalibratePrecision precision;
 	if (!gtk_toggle_button_get_active (togglebutton))
 		return;
-	calib->precision = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (togglebutton),
-								"GcmCalib::precision"));
+	precision = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (togglebutton),
+							 "GcmCalib::precision"));
+	g_object_set (calib->calibrate,
+		      "precision", precision,
+		      NULL);
 }
 
 /**
@@ -1405,7 +1536,10 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *calib)
 	GtkWidget *content;
 	GtkWidget *widget;
 	GSList *list;
-	gchar **labels;
+	GString *labels[3];
+	guint i;
+	guint values_printer[] = { 20, 10, 4}; /* sheets */
+	guint values_display[] = { 20, 10, 4}; /* minutes */
 	GtkAssistant *assistant = GTK_ASSISTANT (calib->main_window);
 
 	/* TRANSLATORS: this is the page title */
@@ -1432,29 +1566,38 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *calib)
 	}
 #endif
 
-	labels = g_new0 (gchar *, 4);
+	/* TRANSLATORS: radio options for calibration precision */
+	labels[0] = g_string_new (_("Accurate"));
+	labels[1] = g_string_new (_("Normal"));
+	labels[2] = g_string_new (_("Quick"));
 	switch (calib->device_kind) {
 	case CD_DEVICE_KIND_PRINTER:
-		/* TRANSLATORS: radio options for calibration precision */
-		labels[0] = g_strdup_printf (_("Accurate (about %i sheets of paper)"), 20);
-		labels[1] = g_strdup_printf (_("Normal (about %i sheets of paper)"), 10);
-		labels[2] = g_strdup_printf (_("Quick (about %i sheets of paper)"), 4);
+		for (i=0; i<3; i++) {
+			g_string_append (labels[i], " ");
+			/* TRANSLATORS: radio options for calibration precision */
+			g_string_append_printf (labels[i], ngettext (
+						"(about %i sheet of paper)",
+						"(about %i sheets of paper)",
+						values_printer[i]),
+						values_printer[i]);
+		}
 		break;
 	case CD_DEVICE_KIND_DISPLAY:
-		/* TRANSLATORS: radio options for calibration precision */
-		labels[0] = g_strdup_printf (_("Accurate (about %i minutes)"), 20);
-		labels[1] = g_strdup_printf (_("Normal (about %i minutes)"), 10);
-		labels[2] = g_strdup_printf (_("Quick (about %i minutes)"), 4);
+		for (i=0; i<3; i++) {
+			g_string_append (labels[i], " ");
+			/* TRANSLATORS: radio options for calibration precision */
+			g_string_append_printf (labels[i], ngettext (
+						"(about %i minute)",
+						"(about %i minutes)",
+						values_display[i]),
+						values_display[i]);
+		}
 		break;
 	default:
-		/* TRANSLATORS: radio options for calibration precision */
-		labels[0] = g_strdup (_("Accurate"));
-		labels[1] = g_strdup (_("Normal"));
-		labels[2] = g_strdup (_("Quick"));
 		break;
 	}
 
-	widget = gtk_radio_button_new_with_label (NULL, labels[0]);
+	widget = gtk_radio_button_new_with_label (NULL, labels[0]->str);
 	g_object_set_data (G_OBJECT (widget),
 			   "GcmCalib::precision",
 			   GUINT_TO_POINTER (GCM_CALIBRATE_PRECISION_LONG));
@@ -1463,7 +1606,7 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *calib)
 	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
 
 	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
-	widget = gtk_radio_button_new_with_label (list, labels[1]);
+	widget = gtk_radio_button_new_with_label (list, labels[1]->str);
 	g_object_set_data (G_OBJECT (widget),
 			   "GcmCalib::precision",
 			   GUINT_TO_POINTER (GCM_CALIBRATE_PRECISION_NORMAL));
@@ -1472,7 +1615,7 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *calib)
 	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
 
 	list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
-	widget = gtk_radio_button_new_with_label (list, labels[2]);
+	widget = gtk_radio_button_new_with_label (list, labels[2]->str);
 	g_object_set_data (G_OBJECT (widget),
 			   "GcmCalib::precision",
 			   GUINT_TO_POINTER (GCM_CALIBRATE_PRECISION_SHORT));
@@ -1489,8 +1632,71 @@ gcm_calib_setup_page_precision (GcmCalibratePriv *calib)
 	g_ptr_array_add (calib->pages, vbox);
 	g_object_set_data (G_OBJECT (vbox),
 			   "GcmCalibrateMain::Index",
-			   GUINT_TO_POINTER (GCM_CALIBRATE_PAGE_DISPLAY_KIND));
-	g_strfreev (labels);
+			   GUINT_TO_POINTER (GCM_CALIBRATE_PAGE_PRECISION));
+
+	for (i=0; i<3; i++)
+		g_string_free (labels[i], TRUE);
+
+	/* show page */
+	gtk_widget_show_all (vbox);
+}
+
+static void
+gcm_calib_text_changed_cb (GtkEntry *entry,
+			   GcmCalibratePriv *calib)
+{
+	g_object_set (calib->calibrate,
+		      "description", gtk_entry_get_text (entry),
+		      NULL);
+}
+
+/**
+ * gcm_calib_setup_page_profile_title:
+ **/
+static void
+gcm_calib_setup_page_profile_title (GcmCalibratePriv *calib)
+{
+	GtkWidget *vbox;
+	GtkWidget *content;
+	GtkWidget *widget;
+	gchar *tmp = NULL;
+	GtkAssistant *assistant = GTK_ASSISTANT (calib->main_window);
+
+	/* TRANSLATORS: this is the page title */
+	vbox = gcm_calib_add_page_title (calib, _("Profile title"));
+
+	/* main contents */
+	content = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), content, FALSE, FALSE, 0);
+
+	/* TRANSLATORS: this is intro page text */
+	gcm_calib_add_page_para (content, _("Choose a title to identify the profile on your system."));
+
+	widget = gtk_entry_new ();
+	gtk_box_pack_start (GTK_BOX (content), widget, FALSE, FALSE, 0);
+	gtk_entry_set_max_length (GTK_ENTRY (widget), 128);
+
+	/* set the current title */
+	g_object_get (calib->calibrate,
+		      "description", &tmp,
+		      NULL);
+	gtk_entry_set_text (GTK_ENTRY (widget), tmp);
+	g_free (tmp);
+
+	/* watch for changes */
+	g_signal_connect (GTK_EDITABLE (widget), "changed",
+			  G_CALLBACK (gcm_calib_text_changed_cb), calib);
+
+	/* add to assistant */
+	gtk_assistant_append_page (assistant, vbox);
+	gtk_assistant_set_page_type (assistant, vbox, GTK_ASSISTANT_PAGE_CONTENT);
+	/* TRANSLATORS: this is the calibration wizard page title */
+	gtk_assistant_set_page_title (assistant, vbox, _("Profile Title"));
+	gtk_assistant_set_page_complete (assistant, vbox, TRUE);
+	g_ptr_array_add (calib->pages, vbox);
+	g_object_set_data (G_OBJECT (vbox),
+			   "GcmCalibrateMain::Index",
+			   GUINT_TO_POINTER (GCM_CALIBRATE_PAGE_TITLE));
 
 	/* show page */
 	gtk_widget_show_all (vbox);
@@ -1649,10 +1855,14 @@ gcm_calib_add_pages (GcmCalibratePriv *calib)
 	gcm_calib_setup_page_precision (calib);
 
 	if (calib->device_kind == CD_DEVICE_KIND_DISPLAY) {
-		if (!calib->internal_lcd)
+		if (!calib->internal_lcd) {
 			gcm_calib_setup_page_display_kind (calib);
-		else
-			calib->display_kind = GCM_CALIBRATE_DEVICE_KIND_LCD;
+		} else {
+			g_object_set (calib->calibrate,
+				      "display-kind", GCM_CALIBRATE_DEVICE_KIND_LCD,
+				      NULL);
+		}
+		gcm_calib_setup_page_display_temp (calib);
 	} else if (calib->device_kind == CD_DEVICE_KIND_PRINTER) {
 		gcm_calib_setup_page_print_kind (calib);
 	} else {
@@ -1662,6 +1872,7 @@ gcm_calib_add_pages (GcmCalibratePriv *calib)
 			gcm_calib_setup_page_install_targets (calib);
 	}
 
+	gcm_calib_setup_page_profile_title (calib);
 	gcm_calib_setup_page_action (calib);
 
 	gcm_calib_setup_page_summary (calib);
@@ -1694,7 +1905,14 @@ gcm_calib_sensor_added_cb (CdClient *client, CdSensor *sensor, GcmCalibratePriv
 static void
 gcm_calib_startup_cb (GApplication *application, GcmCalibratePriv *calib)
 {
+	const gchar *description;
+	const gchar *manufacturer;
+	const gchar *model;
+	const gchar *native_device;
+	const gchar *serial;
+	gchar *copyright = NULL;
 	gboolean ret;
+	GDateTime *dt = NULL;
 	GError *error = NULL;
 
 	/* add application specific icons to search path */
@@ -1761,12 +1979,68 @@ gcm_calib_startup_cb (GApplication *application, GcmCalibratePriv *calib)
 		goto out;
 	}
 
-	/* get the device kind */
+	/* get the device properties */
 	calib->device_kind = cd_device_get_kind (calib->device);
+
+	/* set, with fallbacks */
+	serial = cd_device_get_serial (calib->device);
+	if (serial == NULL) {
+		/* TRANSLATORS: this is saved in the profile */
+		serial = _("Unknown serial");
+	}
+	model = cd_device_get_model (calib->device);
+	if (model == NULL) {
+		/* TRANSLATORS: this is saved in the profile */
+		model = _("Unknown model");
+	}
+	description = cd_device_get_model (calib->device);
+	if (description == NULL) {
+		/* TRANSLATORS: this is saved in the profile */
+		description = _("Unknown description");
+	}
+	manufacturer = cd_device_get_vendor (calib->device);
+	if (manufacturer == NULL) {
+		/* TRANSLATORS: this is saved in the profile */
+		manufacturer = _("Unknown manufacturer");
+	}
+
+	dt = g_date_time_new_now_local ();
+	/* TRANSLATORS: this is the copyright string, where it might be
+	 * "Copyright (c) 2009 Edward Scissorhands"
+	 * BIG RED FLASHING NOTE: YOU NEED TO USE ASCII ONLY */
+	copyright = g_strdup_printf ("%s %04i %s", _("Copyright (c)"),
+				     g_date_time_get_year (dt),
+				     g_get_real_name ());
+
+	/* set the proper values */
+	g_object_set (calib->calibrate,
+		      "device-kind", calib->device_kind,
+		      "model", model,
+		      "description", description,
+		      "manufacturer", manufacturer,
+		      "serial", serial,
+		      "copyright", copyright,
+		      NULL);
+
+	/* display specific properties */
+	if (calib->device_kind == CD_DEVICE_KIND_DISPLAY) {
+		native_device = cd_device_get_metadata_item (calib->device,
+							     CD_DEVICE_METADATA_XRANDR_NAME);
+		if (native_device == NULL) {
+			g_warning ("failed to get output");
+			goto out;
+		}
+		g_object_set (calib->calibrate,
+			      "output-name", native_device,
+			      NULL);
+	}
 out:
 	/* add different pages depending on the device kind */
 	gcm_calib_add_pages (calib);
 	gtk_assistant_set_current_page (GTK_ASSISTANT (calib->main_window), 0);
+	if (dt != NULL)
+		g_date_time_unref (dt);
+	g_free (copyright);
 }
 
 static void
@@ -1873,7 +2147,6 @@ main (int argc, char **argv)
 	calib->brightness = gcm_brightness_new ();
 	calib->calibrate = gcm_calibrate_argyll_new ();
 	calib->device_kind = CD_DEVICE_KIND_UNKNOWN;
-	calib->display_kind = GCM_CALIBRATE_DEVICE_KIND_UNKNOWN;
 	g_signal_connect (calib->calibrate, "title-changed",
 			  G_CALLBACK (gcm_calib_title_changed_cb), calib);
 	g_signal_connect (calib->calibrate, "message-changed",
@@ -1885,10 +2158,8 @@ main (int argc, char **argv)
 
 	/* nothing specified */
 	if (calib->device_id == NULL) {
-		g_print ("did not specify a device ID\n");
-//		calib->device_id = g_strdup ("sysfs-Chicony_Electronics_Co.__Ltd.-Integrated_Camera");
-		calib->device_id = g_strdup ("xrandr-Lenovo Group Limited");
-if(0)		goto out;
+		g_print ("%s\n", _("No device was specified!"));
+		goto out;
 	}
 
 	/* ensure single instance */
